---
layout: default
title: Related
permalink: /related/
---

# Related Articles & Further Information

This website contains visualizations and analysis built from data sources that are updated regularly. However, there are other useful sources of information beyond these visualizations that may be helpful, which we have started to curate here:

**Want to add something to this list? [Edit this file on GitHub](https://github.com/github/covid19-dashboard/blob/master/_pages/related.md) and make a pull request!**


## Data Sources

- [COVID-19 related public projects on GitHub](https://github.com/github/covid-19-repo-data): A comprehensive versioned dataset of the repositories and relevant related metadata about public projects hosted on GitHub related to the 2019 Novel Coronavirus and associated COVID-19 disease.
- The CDC’s [page on the Coronavirus](https://www.cdc.gov/coronavirus/2019-ncov/index.html).
- [2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE](https://github.com/CSSEGISandData/COVID-19): Powers many of the visualizations on this site. This data must be used with care as there are [known issues](https://github.com/CSSEGISandData/COVID-19/issues). This aggregates 14+ data sources from around the world.
- [covidtracking.com](https://covidtracking.com/): Provides an API for detailed data concerning the United States. Includes positive and negative results, pending tests, and total people tested for each state or district currently reporting that data.
- Boston's Children's Hospital [Health Map project](https://healthmap.org/covid-19/).  Includes this [GitHub repo](https://github.com/beoutbreakprepared/nCoV2019) and this [Google sheet](https://docs.google.com/spreadsheets/d/1itaohdPiAeniCXNlntNztZ_oRvjh0HsGuJXUJWET008/edit#gid=0)
- Official Italian government [GitHub repo](https://github.com/pcm-dpc/COVID-19). Updated regularly by the Italian Ministry of Health and Dipartimento di Protezione Civile. Contains multiple indicators such as number of total cases, number in ICU, number of tests done, etc.
- [Folding@Home Dataset](https://github.com/FoldingAtHome/coronavirus):  A dataset that can assist researchers simulating potentially druggable protein targets.
- [Temporal variation in transmission dataset](https://github.com/cmmid/CovidGlobalNow): data that can be used to identify changes in the reproduction number, rate of spread, and doubling time during the course of the COVID-19 outbreak whilst accounting for potential biases due to delays in case reporting.
- [New York Times Dataset](https://github.com/nytimes/covid-19-data): Contains state-level and county-level data based on reports from state and local health agencies. Certain geographical exceptions are present which are mentioned therewith.
- [Models of Infectious Disease Agent Study (MIDAS) Network](https://github.com/midas-network/COVID-19) has listed  computable information (in CSV format) relevant for modeling of the COVID-19 outbreak.

## Articles

- [Why outbreaks like the coronavirus spread exponentially and how to flatten the curve](https://www.washingtonpost.com/graphics/2020/world/corona-simulator/?itid=hp_hp-banner-low_virus-simulator520pm%3Ahomepage%2Fstory-ans) Washington Post, Mar 14, 2020
- [COVID-19 outbreak response: first assessment of mobility changes in Italy following lockdown](https://covid19mm.github.io/in-progress/2020/03/13/first-report-assessment.html) Mar 13, 2020
- [Open letter from Italy to the international scientific community](https://left.it/2020/03/13/covid_19-open-letter-from-italy-to-the-international-scientific-community/) Mar 13, 2020
- [COVID-19, your community, and you — a data science perspective](https://www.fast.ai/2020/03/09/coronavirus/) Mar 9, 2020

## Projects

- [COVID-19 in US and Canada](https://coronavirus.1point3acres.com/): This is the best information I have seen for the US. Even provides case details in some cases. Really well organized dashboard with a plethora of information.
- [nCoV2019.live](https://ncov2019.live/data): Dashboard that presents global statistics about COVID-19 in a tabular format.
- [COVID-19 Clinical Trials Dashboard](https://kishorevasan.shinyapps.io/coronavirus_clinical_trials/): Interactive dashboard that tracks clinical trials related to COVID-19. Uses clinicaltrials.gov data and is updated using API calls.
- [Search Trends for Coronavirus Symptoms, by Country](https://coronavirustracker.webflow.io/): Shows search trends for coronavirus symptoms in the native language of the top-50 populated countries in the world (excluding China).
- [Python Open Source Dashboard](https://covid19-dash.herokuapp.com): Interactive COVID-19 Dashboard, built from scratch in Python on open source Plotly Dash with very few lines of code, including an animating global timeline map. Read 'About this Dashboard' in the Dashboard itself. It‘s open source and open for collaboration.
- [COVID-19 Tracker—Days since N](https://mentalbreaks.shinyapps.io/covid19/): Shiny app that allows users to select countries and compare cumulative outcomes and growth rates on a standardized x-axis. Easy download of plots and filtered data tables in PNG and CSV formats, respectively.
- [Effectiveness of airport screening at detecting travellers infected with novel coronavirus COVID-19](https://cmmid.github.io/visualisations/traveller-screening): Simulation that illustrates the impact of airport screening.
-  [COVID-19 Online Screening Tool - screencovid.com](https://github.com/tconley/screencovid.com):  Assess your risk for COVID-19.
- [Coronavirus Diary](https://github.com/joshua-s/coronavirus-diary): Coronavirus Diary is a mobile application that allows users to complete daily health checkups and receive personalized symptom assessments. If the user experiences symptoms in line with the disease, they will be prompted to contact their physician.
- [A collection of Open Source COVID-19 projects](http://open-source-covid-19.weileizeng.com/). Is a collection of resources on open source, data, analysis, dashboards and maps.
- [corona-cli](https://github.com/AhmadAwais/corona-cli):  🦠 Track the Coronavirus disease (COVID-19) or the Novel Coronavirus Strain in the command line. Both worldwide for all countries, for one country, or for the US States. Fast response time (< 100ms).
- [Genomic Epidemiology](https://nextstrain.org/ncov) of novel coronavirus with visual depiction of genomes sampled between Dec 2019-present.
- [COVID-19 World Monitor](https://thlaegler.github.io/covid-19-monitor): Dashboard combining latest COVID-19 Data with critical/acute Care Capacities, Testing Data and SEIR-Simulation
